@@ -5,12 +5,14 @@
 
 """
 
+from datetime import date
+
 import numpy as np
 import scipy.ndimage as ndimage
-from datetime import date
 from numba.core import types
 from numba.typed import Dict
-from src.mhw_detect.detection.optims import threshAndClim, mhwproperties, appendjit
+
+from src.mhw_detect.detection.optims import appendjit, mhwproperties, threshAndClim
 
 
 def detect(
@@ -205,10 +207,10 @@ def detect(
 
     # Generate vectors for year, month, day-of-month, and day-of-year
     T = len(t)
-    year = np.zeros((T))
-    month = np.zeros((T))
-    day = np.zeros((T))
-    doy = np.zeros((T))
+    year = np.zeros(T)
+    month = np.zeros(T)
+    day = np.zeros(T)
+    doy = np.zeros(T)
     for i in range(T):
         year[i] = date.fromordinal(t[i]).year
         month[i] = date.fromordinal(t[i]).month
@@ -221,9 +223,9 @@ def detect(
         date(year_leapYear, 1, 1).toordinal(),
         date(year_leapYear, 12, 31).toordinal() + 1,
     )
-    month_leapYear = np.zeros((len(t_leapYear)))
-    day_leapYear = np.zeros((len(t_leapYear)))
-    doy_leapYear = np.zeros((len(t_leapYear)))
+    month_leapYear = np.zeros(len(t_leapYear))
+    day_leapYear = np.zeros(len(t_leapYear))
+    doy_leapYear = np.zeros(len(t_leapYear))
     for tt in range(len(t_leapYear)):
         month_leapYear[tt] = date.fromordinal(t_leapYear[tt]).month
         day_leapYear[tt] = date.fromordinal(t_leapYear[tt]).day
@@ -256,10 +258,10 @@ def detect(
         tClim = alternateClimatology[0]
         tempClim = alternateClimatology[1]
         TClim = len(tClim)
-        yearClim = np.zeros((TClim))
-        monthClim = np.zeros((TClim))
-        dayClim = np.zeros((TClim))
-        doyClim = np.zeros((TClim))
+        yearClim = np.zeros(TClim)
+        monthClim = np.zeros(TClim)
+        dayClim = np.zeros(TClim)
+        doyClim = np.zeros(TClim)
         for i in range(TClim):
             yearClim[i] = date.fromordinal(tClim[i]).year
             monthClim[i] = date.fromordinal(tClim[i]).month
