@@ -174,7 +174,7 @@ def extreme_events(
             mask = xr.open_mfdataset(output_path("*.txt.nc"))
             comp = dict(zlib=True)
             encoding = {var: comp for var in mask.data_vars}
-            mask.to_netcdf(output_path(categ_map), encoding=encoding)
+            mask.to_netcdf(output_path(categ_map), encoding=encoding, engine="netcdf4")
             p = [output_path(str(g) + ".txt.nc") for g in range(1, nfile)]
 
             remove_files(p)
