@@ -79,7 +79,7 @@ def mhwproperties(t, temp, clim, n, mhw, categs):
         tt_start = np.where(t == mhw["time_start"][ev])[0][0]
         tt_end = np.where(t == mhw["time_end"][ev])[0][0]
         appendjit(mhw, "index_start", tt_start)
-        appendjit(mhw, "index_end", tt_start)
+        appendjit(mhw, "index_end", tt_end)
         temp_mhw = temp[tt_start : tt_end + 1]
         thresh_mhw = clim["thresh"][tt_start : tt_end + 1]
         seas_mhw = clim["seas"][tt_start : tt_end + 1]
